@@ -147,7 +147,6 @@ impl Zymod {
                 Arg::with_name("log")
                     .short("l")
                     .long("log_config")
-                    .value_name("Log")
                     .help("指定智眼CPU模块日志配置文件")
                     .default_value(log_config_file_path)
                     .takes_value(true),
@@ -184,16 +183,16 @@ impl Zymod {
         log::info!("Content:{}", content);
 
         if self.mod_conf.dry_run == 1 {
-            log::debug!("zymod：在不做任何更改的情况下试运行.....");
+            log::info!("zymod：在不做任何更改的情况下试运行.....");
         } else {
-            log::debug!("zymod：正在上传到agent.....");
+            log::info!("zymod：正在上传到agent.....");
             let run_time = Builder::new_multi_thread().enable_all().build().unwrap();
             let agent_address = format!(
                 "{}:{}",
                 self.mod_conf.agent_host,
                 self.mod_conf.agent_port.to_string()
             );
-            log::debug!("zymod：agentURL:{}", agent_address);
+            log::info!("zymod：agentURL:{}", agent_address);
 
             run_time.block_on(async {
                 let mut client = ZhiYanClient::connect(agent_address).await.unwrap();
